==> yacreader_9.14.2.orig.tar.xz: yacreader-9.14.2.2402143/YACReaderLibraryServer/yacreaderlibraryserver_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="454"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="461"/>
        <source>Unknown error opening the file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="562"/>
        <source>7z not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="568"/>
        <source>Format not supported</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="14"/>
        <source>Log window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="22"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="39"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="56"/>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="73"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="90"/>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="136"/>
        <source>&amp;Auto scroll</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="main.cpp" line="82"/>
        <source>
YACReaderLibraryServer is the headless (no gui) version of YACReaderLibrary.

This appplication support persisten settings, to set them up edit this file %1
To learn about the available settings please check the documentation at https://raw.githubusercontent.com/YACReader/yacreader/develop/YACReaderLibraryServer/SETTINGS_README.md</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="41"/>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="43"/>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="45"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="47"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="49"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="51"/>
        <source>Fatal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::LogWindowModel</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="141"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="143"/>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="145"/>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::Window</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="236"/>
        <source>Save log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="237"/>
        <source>Log file (*.log)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> yacreader_9.16.3.orig.tar.xz: yacreader-9.16.3/YACReaderLibraryServer/yacreaderlibraryserver_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="454"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="461"/>
        <source>Unknown error opening the file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="562"/>
        <source>7z not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="568"/>
        <source>Format not supported</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="14"/>
        <source>Log window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="22"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="39"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="56"/>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="73"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="90"/>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="136"/>
        <source>&amp;Auto scroll</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="main.cpp" line="84"/>
        <source>
YACReaderLibraryServer is the headless (no gui) version of YACReaderLibrary.

This appplication supports persistent settings, to set them up edit this file %1
To learn about the available settings please check the documentation at https://raw.githubusercontent.com/YACReader/yacreader/develop/YACReaderLibraryServer/SETTINGS_README.md</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="41"/>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="43"/>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="45"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="47"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="49"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="51"/>
        <source>Fatal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::LogWindowModel</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="141"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="143"/>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="145"/>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::Window</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="236"/>
        <source>Save log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="237"/>
        <source>Log file (*.log)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
